@@ -11,20 +11,22 @@ sub new {
 sub fittest {
 	my ($self) = @_;
 	my $fitness = 0.0;
+	my $fittest_genome = undef;
 
 	my $metafunction = Evo::Immune::MetaFunction->new(&fitness_M0);
 
 	for (my $i = 0; $i < scalar $self->{population}; $i++) {
-		my $idx1 = 0;
-		my $idx2 = scalar $self->{population}[0]->{genes}; ### FIXME choice of antigens
 		my @args = ();
-		push (@args, $idx1);
-		push (@args, $idx2);
+		my $f = $metafunction->do($self, @args);
 
-		$fitness += $metafunction->do($self, @args);
+		if ($f > $fitness) {
+			$fitness = $f;
+			$fittest_genome = $self->{population}[$i];	
+
+		}
 	}
 
-	return $fitness;
+	return $fittest_genome;
 }
 
 1;
